@@ -121,7 +121,7 @@ public class ReportClient extends AbstractJMXTools {
     }
 
     @Override
-    protected void furtherOptionsHandling(final AdminParser parser, final HashMap<String, String[]> env) {
+    protected void furtherOptionsHandling(final AdminParser parser, final Map<String, String[]> env) {
         try {
             final String combi = (String) parser.getOptionValue(this.showcombi);
             if (null != combi) {
@@ -155,7 +155,7 @@ public class ReportClient extends AbstractJMXTools {
             }
 
             System.out.println("Starting the Open-Xchange report client. Note that the report generation may take a little while.");
-            final MBeanServerConnection initConnection = initConnection(false, env);
+            final MBeanServerConnection initConnection = initConnection(env);
             final List<Total> totals = ObjectHandler.getTotalObjects(initConnection);
             List<ContextDetail> contextDetails = null;
             if (null != parser.getOptionValue(this.advancedreport)) {
